#ifdef PVDIMPORTPLUGIN_EXPORTS
	#define PVDIMPORTPLUGIN_API  extern "C" __declspec(dllexport)
#else
	#define PVDIMPORTPLUGIN_API  extern "C" __declspec(dllimport)
#endif

/*
If you delete a function you have to delete it from the PvdImportPlugin.def too!

Based on the following documentation: http://www.videodb.info/forum_en/index.php?topic=764.0
*/

// Types for movie general import plugins.
typedef bool (*TPluginImpGenMovieCallback)(const WCHAR*);
typedef bool (*TPluginImpGenPersonCallback)(const WCHAR*);

enum PluginType
{
	PLUGIN_UNKNOWN = 0, //You do not need this one actually
	PLUGIN_GENERAL = 1, //Is not currently used
	PLUGIN_WEBIMPORT = 2, //Plugin is importing information from a web service
	PLUGIN_GENIMPORT = 3, //Plugin is importing information from other type of database
	PLUGIN_WEBPICIMPORT = 4, //Plugin is importing Posters from a web service
	PLUGIN_WEBCOVERIMPORT = 5, //Plugin is importing Cover and Disc images from a web service
	PLUGIN_WEBPEOPLEIMPORT = 6, //Plugin is importing information about people from a web service
	PLUGIN_EXPORT = 7, //Export plugin
};

enum PluginError
{
  ERR_PLUG_OK            = 0,
  ERR_PLUG_NEEDCONFIGURE = 1,
};

///////////////////////////////////////////////////////////////////////////////
// Common functions for all types of plugins
///////////////////////////////////////////////////////////////////////////////

// This function must be present in all plugins. It should return the type of the plugin (see the PluginType enum).
PVDIMPORTPLUGIN_API SHORT __stdcall GetType();

// This function must be present in all plugins. It should return a short name of the plugin.
// LangID: Currently selected user interface language
PVDIMPORTPLUGIN_API WCHAR* __stdcall GetName(int LangID);

// This function must be present in all plugins. It should return the description of the plugin.
// LangID: Currently selected user interface language
PVDIMPORTPLUGIN_API WCHAR* __stdcall GetDescription(int LangID);

// This function must be present in all plugins. It should return minimum supported Personal Video Database version. Use 0 for all versions.
// Version is assumed to be a number like:
// 001005000000 = 1005000 = "1.5.0.0"
// 000009000000 = 9000 = "0.9.0.0"
PVDIMPORTPLUGIN_API DWORD __stdcall GetVersionSupported();

// Returns the version of the plugin. This function is not obligatory and can be absent in the plugin.
PVDIMPORTPLUGIN_API char* __stdcall GetPluginVersion();

// This function is also not obligatory. If Personal Video Database finds this function it passes it's version to it.
// The function should return True if the plugin is compatible with the passed version of the program and False otherwise.
PVDIMPORTPLUGIN_API bool __stdcall CheckPVDVerion(int V);

// Returns the language of the plugin. It is useful especially for Web Import plugins to pass the language of the information they are getting from Web.
// If this function is not present English is assumed.
PVDIMPORTPLUGIN_API int __stdcall GetPluginLanguage();

// Returns information about the plugin. Not obligatory.
// LangID: Currently selected user interface language
PVDIMPORTPLUGIN_API WCHAR* __stdcall GetAbout(int LangID);

// This function must return true if the plugin is configurable and false otherwise. If no such function is found in the plugin false is assumed.
PVDIMPORTPLUGIN_API bool __stdcall CanConfig();

// This function is called when a user wants to configure a plugin. Return true if configuration was successful.
// LangID: Currently selected user interface language
// AppHandle: Handle of the application window
// pCustomFields: List of custom fields (#0 - separator, #8#0 - end of the list)
PVDIMPORTPLUGIN_API bool __stdcall Configure(int LangID, HWND AppHandle, WCHAR* pCustomFields);

// Obligatory function. It is called each time the main program starts to work with the plugin.
// See the PluginError enum for possible return values.
PVDIMPORTPLUGIN_API int __stdcall BeginWork();

// Obligatory function. Called each time the work with the plugin is finished.
PVDIMPORTPLUGIN_API void __stdcall EndWork();

///////////////////////////////////////////////////////////////////////////////
// General import plugins
///////////////////////////////////////////////////////////////////////////////

// This function must return a filter for the File Open Dialog, when selecting a file to import from.
// AppHandle: Handle of the application window
// LangID: Currently selected user interface language
// pCustomFields: List of custom fields (#0 - separator, #8#0 - end of the list)
PVDIMPORTPLUGIN_API WCHAR* __stdcall GetFilter(HWND AppHandle, int LangID, WCHAR* pCustomFields);

// This procedure must be present in this type of plugins. It is called just after the user selected the file to import from.
// LangID: Currently selected user interface language
// AppHandle: Handle of the application window
// pFileName: Name of the file to import from.
// MovieCallback: A callback procedure that should be called from the plugin every time a movie should be added to the database.
// HumanCallback: A callback procedure that should be called from the plugin every time a human should be added to the database.
// pCustomFields: List of custom fields (#0 - separator, #8#0 - end of the list)
PVDIMPORTPLUGIN_API void __stdcall Parse(HWND AppHandle, int LangID, WCHAR* pFileName, TPluginImpGenMovieCallback MovieCallback, TPluginImpGenPersonCallback HumanCallback, WCHAR* pCustomFields);